@@ -21,7 +21,9 @@ struct scfg_directive {
 };
 
 int scfg_load_file(struct scfg_block *block, const char *path);
+int scfg_store_file(const struct scfg_block *block, const char *path);
 int scfg_parse_file(struct scfg_block *block, FILE *f);
+int scfg_format_file(const struct scfg_block *block, FILE *f);
 void scfg_block_finish(struct scfg_block *block);
 
 #endif
